@@ -39,6 +39,7 @@ from .resources.settlement_payments import SettlementPayments
 from .resources.settlement_refunds import SettlementRefunds
 from .resources.settlements import Settlements
 from .resources.subscription_payments import SubscriptionPayments
+from .resources.subscriptions import Subscriptions
 from .version import VERSION
 
 
@@ -112,6 +113,7 @@ class Client(object):
         self.settlement_refunds = SettlementRefunds(self)
         self.settlement_chargebacks = SettlementChargebacks(self)
         self.settlement_captures = SettlementCaptures(self)
+        self.subscriptions = Subscriptions(self)
 
         # compose base user agent string
         self.user_agent_components = OrderedDict()
